library(readxl)
library(ggplot2)

sapsdatawc <- read_excel("saps2.xlsx", sheet = "Western Cape")
str(sapsdatawc)

range(sapsdatawc$police_per_100k)
range(sapsdatawc$murders_per_100k)

plot <- ggplot(data = sapsdatawc, aes(x = police_per_100k, y = murders_per_100k)) +
  geom_point() +
  geom_smooth(method = lm, se = FALSE) +
  theme_bw() +
  scale_y_continuous(limits = c(0,200), breaks = seq(0,200,20)) +
  scale_x_continuous(limits = c(0,3200), breaks = seq(0,3000,500)) +
  xlab("Police / 100,000 population (2015/16)") +
  ylab("Murders / 100,000 population (average 2015/16)")
plot
ggsave("plotWCv1.png", w=6.8,h=5.12,dpi=600)

# Exclude the outlier (Table Bay Harbour)

plot <- ggplot(data = sapsdatawc, aes(x = police_per_100k, y = murders_per_100k)) +
  geom_point() +
  geom_smooth(method = lm, se = FALSE) +
  theme_bw() +
  scale_y_continuous(limits = c(0,200), breaks = seq(0,200,20)) +
  scale_x_continuous(limits = c(0,1800), breaks = seq(0,1800,200)) +
  xlab("Police / 100,000 population (2015/16)") +
  ylab("Murders / 100,000 population (average 2015/16)")
plot
ggsave("plotWCv2.png", w=6.8,h=5.12,dpi=600)

# Information on the linear model:

model <- lm(murders_per_100k ~ police_per_100k, data = sapsdatawc)
WC_Summary = summary(model)

WC_Cor = cor(sapsdatawc$murders_per_100k, sapsdatawc$police_per_100k)

sapsdatawc <- read_excel("saps2.xlsx", sheet = "All")
str(sapsdatawc)

range(sapsdatawc$police_per_100k)
range(sapsdatawc$murders_per_100k)

plot <- ggplot(data = sapsdatawc, aes(x = police_per_100k, y = murders_per_100k)) +
  geom_point() +
  geom_smooth(method = lm, se = FALSE) +
  theme_bw() +
  scale_y_continuous(limits = c(0,200), breaks = seq(0,200,20)) +
  scale_x_continuous(limits = c(0,3200), breaks = seq(0,3000,500)) +
  xlab("Police / 100,000 population (2015/16)") +
  ylab("Murders / 100,000 population (average 2015/16)")
plot
ggsave("plotAllv1.png", w=6.8,h=5.12,dpi=600)

# Exclude the outlier (Table Bay Harbour)

plot <- ggplot(data = sapsdatawc, aes(x = police_per_100k, y = murders_per_100k)) +
  geom_point() +
  geom_smooth(method = lm, se = FALSE) +
  theme_bw() +
  scale_y_continuous(limits = c(0,200), breaks = seq(0,200,20)) +
  scale_x_continuous(limits = c(0,1800), breaks = seq(0,1800,200)) +
  xlab("Police / 100,000 population (2015-16)") +
  ylab("Murders / 100,000 population (average 2015-16)")
plot
ggsave("plotAllv2.png", w=6.8,h=5.12,dpi=600)

# Information on the linear model:

model <- lm(murders_per_100k ~ police_per_100k, data = sapsdatawc)
SA_Summary = summary(model)

SA_Cor = cor(sapsdatawc$murders_per_100k, sapsdatawc$police_per_100k)

